@@ -22,6 +22,7 @@ SPDX-License-Identifier: GPL-2.0-or-later
 #include <KConfigPropertyMap>
 #include <KCrash>
 #include <KLocalizedContext>
+#include <KLocalizedQmlContext>
 #include <KScreenDpms/Dpms>
 #include <KWindowSystem>
 #include <PlasmaQuick/QuickViewSharedEngine>
@@ -331,7 +332,7 @@ PlasmaQuick::QuickViewSharedEngine *UnlockApp::createViewForScreen(QScreen *scre
     });
 
     view->engine()->setProperty("_kirigamiTheme", QStringLiteral("KirigamiPlasmaStyle"));
-    view->engine()->rootContext()->setContextObject(new KLocalizedContext(view->engine().get()));
+    view->engine()->rootContext()->setContextObject(new KLocalizedQmlContext(view->engine().get()));
     auto oldFactory = view->engine()->networkAccessManagerFactory();
     view->engine()->setNetworkAccessManagerFactory(nullptr);
     delete oldFactory;
@@ -618,7 +619,7 @@ bool UnlockApp::eventFilter(QObject *obj, QEvent *event)
         if (ke->key() != Qt::Key_Escape) {
             shareEvent(event, qobject_cast<PlasmaQuick::QuickViewSharedEngine *>(obj));
             return false; // irrelevant
-        } else {
+        } else if (!m_testing) { // don't turn screen off in testing mode.
             auto dpms = new KScreen::Dpms(this);
             if (dpms->isSupported()) {
                 connect(dpms, &KScreen::Dpms::hasPendingChangesChanged, this, [dpms](bool hasPendingChanges) {
