@@ -16,6 +16,8 @@ class PamAuthenticator : public QObject
     Q_OBJECT
 
     Q_PROPERTY(bool busy READ isBusy NOTIFY busyChanged)
+    Q_PROPERTY(bool available READ isAvailable NOTIFY availableChanged)
+    Q_PROPERTY(NoninteractiveAuthenticatorTypes authenticatorType READ authenticatorType CONSTANT)
 
     Q_PROPERTY(QString prompt READ getPrompt NOTIFY prompt)
     Q_PROPERTY(QString promptForSecret READ getPromptForSecret NOTIFY promptForSecret)
@@ -26,11 +28,25 @@ class PamAuthenticator : public QObject
     Q_PROPERTY(bool unlocked READ isUnlocked NOTIFY succeeded)
 
 public:
-    PamAuthenticator(const QString &service, const QString &user, QObject *parent = nullptr);
-    ~PamAuthenticator();
+    enum NoninteractiveAuthenticatorType {
+        None = 0,
+        Fingerprint = 1 << 0,
+        Smartcard = 2 << 0,
+    };
+    Q_DECLARE_FLAGS(NoninteractiveAuthenticatorTypes, NoninteractiveAuthenticatorType)
+    Q_FLAG(NoninteractiveAuthenticatorTypes)
+
+    PamAuthenticator(const QString &service,
+                     const QString &user,
+                     NoninteractiveAuthenticatorTypes authenticatorType = NoninteractiveAuthenticatorType::None,
+                     QObject *parent = nullptr);
+    ~PamAuthenticator() override;
+    Q_DISABLE_COPY_MOVE(PamAuthenticator)
 
     bool isBusy() const;
     bool isUnlocked() const;
+    bool isAvailable() const;
+    NoninteractiveAuthenticatorTypes authenticatorType() const;
 
     // Get prefix to de-duplicate from their signals.
     QString getPrompt() const;
@@ -38,6 +54,8 @@ public:
     QString getInfoMessage() const;
     QString getErrorMessage() const;
 
+    QString service() const;
+
 Q_SIGNALS:
     void busyChanged();
     void promptForSecret(const QString &msg);
@@ -46,6 +64,7 @@ Q_SIGNALS:
     void errorMessage(const QString &msg);
     void succeeded();
     void failed();
+    void availableChanged();
 
 public Q_SLOTS:
     void tryUnlock();
@@ -54,7 +73,6 @@ public Q_SLOTS:
 
 protected:
     void init(const QString &service, const QString &user);
-    void connectNotify(const QMetaMethod &signal) override;
 
 private:
     void setBusy(bool busy);
@@ -65,8 +83,14 @@ private:
     QString m_promptForSecret;
     QString m_errorMessage;
     QString m_infoMessage;
+    QString m_service;
     bool m_busy = false;
     bool m_unlocked = false;
+    bool m_inAuthentication = false;
+    bool m_unavailable = false;
+    NoninteractiveAuthenticatorTypes m_authenticatorType;
     QThread m_thread;
     PamWorker *d;
 };
+
+Q_DECLARE_OPERATORS_FOR_FLAGS(PamAuthenticator::NoninteractiveAuthenticatorTypes)
